from .phrase_tms_api_models import (
    ADMIN,
    ADMINEDIT,
    ADMINRESPONSE,
    AbsoluteTranslationLengthWarningDto,
    AbstractAnalyseSettingsDto,
    AbstractProjectDto,
    AbstractProjectDtoV2,
    AbstractUserCreateDto,
    AbstractUserEditDto,
    AccuracyWeightsDto,
    Action,
    Action1,
    AddCommentDto,
    AddLqaCommentResultDto,
    AddPlainCommentResultDto,
    AddTargetLangDto,
    AddWorkflowStepsDto,
    AdditionalWorkflowStepDto,
    AdditionalWorkflowStepRequestDto,
    AdditionalWorkflowStepV2Dto,
    AdminProjectManager,
    AdminProjectManagerV2,
    AllowedEntity,
    AnalyseJobDto,
    AnalyseJobReference,
    AnalyseLanguagePartDto,
    AnalyseLanguagePartReference,
    AnalyseLanguagePartV2Dto,
    AnalyseLanguagePartV3Dto,
    AnalyseRecalculateRequestDto,
    AnalyseRecalculateResponseDto,
    AnalyseReference,
    AnalyseSettingsDto,
    AnalyseV2Dto,
    AnalyseV3Dto,
    AnalysesV2Dto,
    AnalysisType_1,
    AnalysisType_2,
    AnalysisType_3,
    AndroidSettingsDto,
    AppleTokenResponseDto,
    AsciidocSettingsDto,
    AssessmentBasicDto,
    AssessmentDetailDto,
    AssessmentDetailsDto,
    AssessmentRequestDto,
    AssessmentResultDto,
    AssessmentResultsDto,
    AssignVendorDto,
    AssignableTemplatesDto,
    AssignedJobDto,
    AssignmentPerTargetLangDto,
    AsyncAnalyseListResponseDto,
    AsyncAnalyseListResponseV2Dto,
    AsyncAnalyseResponseDto,
    AsyncAnalyseResponseV2Dto,
    AsyncExportTMByQueryDto,
    AsyncExportTMByQueryResponseDto,
    AsyncExportTMDto,
    AsyncExportTMResponseDto,
    AsyncFileOpResponseDto,
    AsyncRequestDto,
    AsyncRequestReference,
    AsyncRequestReferenceDto,
    AsyncRequestStatusDto,
    AsyncRequestType,
    AsyncRequestV2Dto,
    AsyncRequestWrapperDto,
    AsyncRequestWrapperV2Dto,
    AsyncResponseDto,
    AsyncResponseV2Dto,
    Attribute,
    AttributeType,
    AuthSchema,
    AutomatedProjectSettingsDto,
    Availability,
    BackgroundTaskReference,
    BackgroundTasksTbDto,
    BackgroundTasksTmDto,
    BillingUnit,
    BillingUnit2,
    BrowseRequestDto,
    BrowseResponseListDto,
    BulkDeleteAnalyseDto,
    BulkDeleteTmDto,
    BulkEditAnalyseV2Dto,
    BusinessUnitDto,
    BusinessUnitEditDto,
    BusinessUnitReference,
    BusinessUnitReference2,
    BusinessUnitReference3,
    Buyer,
    BuyerDto,
    BuyerEditDto,
    BuyerReference,
    CellFlow,
    CheckResponse,
    CleanedTransMemoriesDto,
    CleanupTask,
    ClientDto,
    ClientEditDto,
    ClientReference,
    ClientReference2,
    ClientReference3,
    CloneProjectDto,
    CommentDto,
    CommonConversationDto,
    ComparedSegmentDto,
    ComparedSegmentsDto,
    ConceptDto,
    ConceptDtov2,
    ConceptEditDto,
    ConceptListReference,
    ConceptListResponseDto,
    ConceptWithMetadataDto,
    ConcurrentRequestsDto,
    ConnectorAsyncTaskStateDto,
    ConnectorAsyncTaskStatesDto,
    ConnectorDto,
    ConnectorErrorDetailDto,
    ConnectorErrorsDto,
    ConnectorListDto,
    ConnectorType,
    ContextKeySuffixType,
    ContextType,
    ContinuousJobInfoDto,
    ConversationListDto,
    CostCenterDto,
    CostCenterEditDto,
    CostCenterReference,
    CostCenterReference2,
    CountsDto,
    CountsDto2,
    CountsDto3,
    CreateAnalyseAsyncV2Dto,
    CreateAnalyseListAsyncDto,
    CreateCustomFieldDto,
    CreateCustomFieldInstanceDto,
    CreateCustomFieldInstancesDto,
    CreateCustomFileTypeDto,
    CreateLqaConversationDto,
    CreateLqaProfileDto,
    CreatePlainConversationDto,
    CreateProjectFromTemplateAsyncV2Dto,
    CreateProjectFromTemplateV2Dto,
    CreateProjectV3Dto,
    CreateReferenceFileNoteDto,
    CreateReferenceFilesRequest,
    CreateTermsDto,
    CreateVendorDto,
    CreateWebEditorLinkDtoV2,
    CreateWebHookDto,
    CreateWorkflowStepDto,
    CsvSettingsDto,
    CustomFieldDto,
    CustomFieldInstanceApiDto,
    CustomFieldInstanceApiV3Dto,
    CustomFieldInstanceDto,
    CustomFieldInstancesDto,
    CustomFieldOptionDto,
    CustomFieldOptionsTruncatedDto,
    CustomFileTypeDto,
    CustomFiletypeType,
    CustomQAWarningDto,
    CustomfieldType,
    DashboardSetting,
    DataDto,
    DataDto2,
    DataDtoV1,
    DeleteCustomFileTypeDto,
    DeleteVendorsDto,
    DelimiterType,
    DesignWeightsDto,
    DictionaryItemDto,
    Direction,
    DiscountSchemeCreateDto,
    DiscountSchemeReference,
    DiscountSchemeReference2,
    DiscountSettingsDto,
    DitaSettingsDto,
    DocBookSettingsDto,
    DocSettingsDto,
    DomainDto,
    DomainEditDto,
    DomainReference,
    DomainReference2,
    DomainReference3,
    DownloadTargetFileDto,
    EditAnalyseSettingsDto,
    EditAnalyseV2Dto,
    EditLqaConversationDto,
    EditPlainConversationDto,
    EditProjectMTSettPerLangDto,
    EditProjectMTSettPerLangListDto,
    EditProjectMTSettingsDto,
    EditProjectSecuritySettingsDtoV2,
    EditProjectV2Dto,
    EditProjectV3Dto,
    EditQASettingsDtoV2,
    EditSegmentationRuleDto,
    EditWorkflowStepDto,
    EditionDto,
    Email,
    EmailQuotesRequestDto,
    EmailQuotesResponseDto,
    EmailTemplateType,
    EmptyPairTagsWarningDto,
    EmptyTagContentWarningDto,
    EmptyTranslationWarningDto,
    EnabledCheck,
    EnabledCheckContextDtoV2,
    EnabledCheckContextDtoV4,
    EnabledCheckDtoV2,
    EnabledCheckDtoV4,
    EnabledQualityChecksDto,
    ErrorCategoriesDto,
    ErrorDetailDto,
    ErrorDetailDtoV2,
    ErrorDetailDtoV3,
    ErrorDto,
    ErrorsReference,
    Event,
    ExportByQueryDto,
    ExportTMDto,
    ExtraNumbersV3WarningDto,
    ExtraNumbersWarningDto,
    FeaturesDto,
    FileDto,
    FileFormat,
    FileHandoverDto,
    FileImportSettingsCreateDto,
    FileImportSettingsDto,
    FileListDto,
    FileNamingSettingsDto,
    Filter,
    FinancialSettingsDto,
    FindConversationsDto,
    FindConversationsForProjectDto,
    FinishAssessmentDto,
    FinishAssessmentItemDto,
    FinishAssessmentsDto,
    Flavor,
    FluencyWeightsDto,
    ForbiddenStringWarningDto,
    ForbiddenTermWarningDto,
    FormattingWarningDto,
    FuzzyInconsistencyWarningDto,
    GUEST,
    GUESTEDIT,
    GUESTRESPONSE,
    Gender,
    GetBilingualFileDto,
    GetFileRequestParamsDto,
    GlossaryActivationDto,
    GlossaryDto,
    GlossaryEditDto,
    GlossarySimpleDto,
    HtmlSettingsDto,
    HumanTranslateJobsDto,
    IdReference,
    IdmUserReference,
    IdmlSettingsDto,
    ImportSetSegmentConfirmedWhen,
    ImportSettingsCreateDto,
    ImportSettingsDto,
    ImportSettingsEditDto,
    ImportSettingsReference,
    ImportStatusDto,
    ImportStatusDtoV2,
    ImportTermBaseResponseDto,
    InconsistentTagContentWarningDto,
    InconsistentTranslationWarningDto,
    InputStream,
    InputStreamLength,
    IssueCountsDto,
    JobCreateRemoteFileDto,
    JobCreateRequestDto,
    JobExportActionDto,
    JobExportResponseDto,
    JobListDto,
    JobMachineTranslationSettingsV3Dto,
    JobNonTranslatableSettingsV3Dto,
    JobPartDeleteReferences,
    JobPartExtendedDto,
    JobPartPatchBatchDto,
    JobPartPatchResultDto,
    JobPartPatchSingleDto,
    JobPartReadyDeleteTranslationDto,
    JobPartReadyDeleteTranslationFilterDto,
    JobPartReadyReferences,
    JobPartReadyReferences2,
    JobPartReference,
    JobPartReferenceV2,
    JobPartReferences,
    JobPartSegmentsDtoV3,
    JobPartStatusChangeDto,
    JobPartStatusChangesDto,
    JobPartUpdateBatchDto,
    JobPartUpdateSingleDto,
    JobPartUpdateSourceDto,
    JobPartsDto,
    JobReference,
    JobRemoteFileReference,
    JobRoleDto,
    JobSegmentDto,
    JobStatusChangeActionDto,
    JobTranslationMemorySettingsV3Dto,
    JobUpdateSourceResponseDto,
    JobWidgetReference,
    JobroleType,
    JoinTagsWarningDto,
    JsonSettingsDto,
    LINGUIST,
    LINGUISTEDIT,
    LINGUISTRESPONSE,
    LQA,
    LQAConversationDto,
    LQAConversationsListDto,
    LQAReference,
    LQAReferences,
    LanguageDto2,
    LanguageListDto,
    LanguageMetadata,
    LanguageMetadata1,
    LastLoginDto,
    LeadingAndTrailingSpacesWarningDto,
    Level,
    Linguist,
    LinguistV2,
    LocaleConventionWeightsDto,
    LocaleFormat,
    LoginDto,
    LoginOtherDto,
    LoginOtherV3Dto,
    LoginResponseDto,
    LoginResponseV3Dto,
    LoginToSessionDto,
    LoginToSessionResponseDto,
    LoginToSessionResponseV3Dto,
    LoginToSessionV3Dto,
    LoginUserDto,
    LoginV3Dto,
    LoginWithAppleDto,
    LoginWithGoogleDto,
    LqaErrorCategoryDto,
    LqaProfileAssessmentDto,
    LqaProfileDetailDto,
    LqaProfileReferenceDto,
    LqaProfilesForWsV2Dto,
    LqaProfilesForWsV3Dto,
    LqaRecipientType,
    LqaReportEmailRequestDto,
    LqaReportLinkDto,
    LqaReportRecipientDto,
    LqaSettingsDto,
    LqaSeverityDto,
    MORAVIA,
    MTSettingsPerLanguageDto,
    MTSettingsPerLanguageListDto,
    MTSettingsPerLanguageReference,
    MacSettingsDto,
    MachineTranslateResponse,
    MachineTranslateSettingsDto,
    MachineTranslateSettingsLangsDto,
    MachineTranslateSettingsPbmDto,
    MachineTranslateSettingsReference,
    MachineTranslateSettingsSimpleDto,
    MachineTranslateStatusDto,
    MachineTranslationBehavior,
    MachineTranslationSettingsDto5,
    MalformedWarningDto,
    Match,
    MatchCounts101Dto,
    MatchCounts101Dto2,
    MatchCounts101Dto3,
    MatchCountsDto,
    MatchCountsDto2,
    MatchCountsDto3,
    MatchCountsNTDto,
    MatchCountsNTDto2,
    MatchCountsNTDtoV1,
    MdSettingsDto,
    MemTransMachineTranslateSettingsDto,
    MemsourceTranslateProfileDto,
    MemsourceTranslateProfileSimpleDto,
    MentionDto,
    MentionGroupType,
    MentionType,
    MentionableGroupDto,
    MentionableUserDto,
    MetadataField,
    MetadataOptionReference,
    MetadataPrioritySettingsDto,
    MetadataReference,
    MetadataResponse,
    MetadataResponse_2,
    MetadataTbDto,
    MetadataType,
    MifSettingsDto,
    MissingNonTranslatableAnnotationWarningDto,
    MissingNumbersV3WarningDto,
    MissingNumbersWarningDto,
    MisspelledWord,
    MisspelledWordDto,
    Mode,
    MoraviaWarningDto,
    MultilingualCsvSettingsDto,
    MultilingualXlsSettingsDto,
    MultilingualXmlSettingsDto,
    MultipartFile,
    MultipleSpacesV3WarningDto,
    MultipleSpacesWarningDto,
    Mutability,
    NUMBER,
    Name,
    NameDto,
    NestedTagsWarningDto,
    NetRateScheme,
    NetRateSchemeEdit,
    NetRateSchemeReference,
    NetRateSchemeWorkflowStep,
    NetRateSchemeWorkflowStepCreate,
    NetRateSchemeWorkflowStepEdit,
    NetRateSchemeWorkflowStepReference,
    NewerAtLowerLevelWarningDto,
    NonConformingTermWarningDto,
    NonEmptySegmentAction,
    NonTranslatableSettingsDto5,
    NotConfirmedWarningDto,
    NotificationDto,
    NotifyJobPartsRequestDto,
    NotifyProviderDto,
    Number,
    Number1,
    ObjectReference,
    Order,
    OrganizationEmailTemplateDto,
    OrganizationReference,
    OrganizationReference2,
    OrganizationType,
    Origin,
    Origin1,
    OtherWeightsDto,
    OutputFormat,
    PORTALMEMBER,
    PORTALMEMBEREDIT,
    PORTALMEMBERRESPONSE,
    PROJECTMANAGER,
    PROJECTMANAGEREDIT,
    PROJECTMANAGERRESPONSE,
    PageDtoAbstractProjectDto,
    PageDtoAdditionalWorkflowStepDto,
    PageDtoAnalyseJobDto,
    PageDtoAnalyseReference,
    PageDtoAssignedJobDto,
    PageDtoAsyncRequestDto,
    PageDtoBusinessUnitDto,
    PageDtoBuyerDto,
    PageDtoClientDto,
    PageDtoCommonConversationDto,
    PageDtoCostCenterDto,
    PageDtoCustomFieldDto,
    PageDtoCustomFieldInstanceDto,
    PageDtoCustomFieldOptionDto,
    PageDtoCustomFileTypeDto,
    PageDtoDomainDto,
    PageDtoGlossaryDto,
    PageDtoImportSettingsReference,
    PageDtoJobPartReferenceV2,
    PageDtoLastLoginDto,
    PageDtoLqaProfileReferenceDto,
    PageDtoLqaReportRecipientDto,
    PageDtoMachineTranslateSettingsPbmDto,
    PageDtoMemsourceTranslateProfileDto,
    PageDtoNetRateSchemeReference,
    PageDtoNetRateSchemeWorkflowStepReference,
    PageDtoOrganizationEmailTemplateDto,
    PageDtoProjectReference,
    PageDtoProjectTemplateReference,
    PageDtoProviderReference,
    PageDtoQuoteDto,
    PageDtoSegmentationRuleDto,
    PageDtoString,
    PageDtoSubDomainDto,
    PageDtoTermBaseDto,
    PageDtoTransMemoryDto,
    PageDtoTranslationPriceListDto,
    PageDtoTranslationPriceSetDto,
    PageDtoUploadedFileDto,
    PageDtoUserDto,
    PageDtoUserReference,
    PageDtoVendorDto,
    PageDtoWebHookDtoV2,
    PageDtoWebhookCallDto,
    PageDtoWorkflowStepDto,
    PageDtoWorkflowStepReference,
    PageDtoXmlAssistantProfileListDto,
    PageRequest,
    PageWithResponseTsDtoNotificationDto,
    PartOfSpeech,
    PassFailThresholdDto,
    PatchProjectDto,
    PdfSettingsDto,
    PenaltyPointsDto,
    PhpSettingsDto,
    PlainConversationDto,
    PlainConversationsListDto,
    PlainReferences,
    PoSettingsDto,
    Position,
    PostAnalyse,
    PptSettingsDto,
    PreAnalyse,
    PreAnalyseTargetCompare,
    PreTranslateJobSettingsV3Dto,
    PreTranslateJobsV3Dto,
    PreTranslateSettingsV4Dto,
    PreviewUrlDto,
    PreviewUrlType,
    PreviewUrlsDto,
    PreviousWorkflowDto,
    PriceListReference,
    ProgressDto,
    ProgressDtoV2,
    ProgressReference,
    ProjectJobPartsDto,
    ProjectMTSettingsPerLangDto,
    ProjectReference,
    ProjectReference2,
    ProjectReferenceFilesRequestDto,
    ProjectSecuritySettingsDtoV2,
    ProjectTemplate,
    ProjectTemplateCreateActionDto,
    ProjectTemplateDto,
    ProjectTemplateEditDto,
    ProjectTemplateEditV2Dto,
    ProjectTemplateNotifyProviderDto,
    ProjectTemplateReference,
    ProjectTemplateTermBaseDto,
    ProjectTemplateTermBaseListDto,
    ProjectTemplateTransMemoryDtoV3,
    ProjectTemplateTransMemoryListDtoV3,
    ProjectTemplateTransMemoryListV2Dto,
    ProjectTemplateTransMemoryV2Dto,
    ProjectTemplateWorkflowSettingsAssignedToDto,
    ProjectTemplateWorkflowSettingsDto,
    ProjectTermBaseDto,
    ProjectTermBaseListDto,
    ProjectTermBaseReference,
    ProjectTransMemoryDtoV3,
    ProjectTransMemoryListDtoV3,
    ProjectTranslationMemoryReference,
    ProjectWorkflowSettingsDto,
    ProjectWorkflowSettingsReference,
    ProjectWorkflowSettingsV2Dto,
    ProjectWorkflowStepDto,
    ProjectWorkflowStepDtoV2,
    ProjectWorkflowStepListDtoV2,
    ProjectWorkflowStepReference,
    PropertiesSettingsDto,
    ProviderListDtoV2,
    ProviderReference,
    ProviderReference2,
    Providers2,
    ProvidersPerLanguage,
    PsdSettingsDto,
    PseudoTranslateActionDto,
    PseudoTranslateActionDtoV2,
    PseudoTranslateWrapperDto,
    QACheckDtoV2,
    QASettingsDtoV2,
    QaCheckName,
    QaCheckType,
    QualityAssuranceBatchRunDtoV3,
    QualityAssuranceChecksDtoV2,
    QualityAssuranceChecksDtoV4,
    QualityAssuranceDto,
    QualityAssuranceResponseDto,
    QualityAssuranceRunDtoV3,
    QualityAssuranceSegmentsRunDtoV3,
    QuarkTagSettingsDto,
    Query,
    QuoteCreateV2Dto,
    QuoteDto,
    QuoteType,
    QuoteUnitsDto,
    QuoteV2Dto,
    QuoteWorkflowSettingDto,
    REGEX,
    ReferenceCorrelation,
    ReferenceFileAccessDto,
    ReferenceFilePageDto,
    ReferenceFileReference,
    ReferenceFilesDto,
    RegexpCheckRuleDtoV2,
    RegexpCheckRuleDtoV4,
    RelativeTranslationLengthWarningDto,
    RemoteUploadedFileDto,
    Repeated,
    RepeatedWordWarningDto,
    RepeatedWordsWarningDto,
    RepetitionsSettingsDto4,
    ReplayRequestDto,
    ResxSettingsDto,
    Returned,
    ReviewProviderDto,
    Role,
    Role4,
    Role5,
    RulesFormat,
    RunAutoLqaDto,
    SEGMENTTARGET,
    STRING,
    SUBMITTER,
    SUBMITTEREDIT,
    SUBMITTERRESPONSE,
    SchemaExtension,
    ScimMeta,
    ScimResourceSchema,
    ScimResourceTypeSchema,
    ScimUserCoreDto,
    ScoringResultDto,
    ScoringResultIssueCountsDto,
    SdlXlfSettingsDto,
    SearchInTextResponse2Dto,
    SearchInTextResponseList2Dto,
    SearchJobsDto,
    SearchJobsRequestDto,
    SearchRequestDto,
    SearchResponseListTbDto,
    SearchResponseListTmDto,
    SearchResponseListTmDtoV3,
    SearchResponseTbDto,
    SearchTMByJobRequestDto,
    SearchTMByJobRequestDtoV3,
    SearchTMClientDto,
    SearchTMClientDtoV3,
    SearchTMDomainDto,
    SearchTMDomainDtoV3,
    SearchTMProjectDto,
    SearchTMProjectDtoV3,
    SearchTMRequestDto,
    SearchTMResponseDto,
    SearchTMResponseDtoV3,
    SearchTMSegmentDto,
    SearchTMSegmentDtoV3,
    SearchTMSubDomainDto,
    SearchTMSubDomainDtoV3,
    SearchTMTransMemoryDto,
    SearchTMTransMemoryDtoV3,
    SearchTbByJobRequestDto,
    SearchTbInTextByJobRequestDto,
    SearchTbResponseDto,
    SearchTbResponseListDto,
    SecuritySettingsReference,
    SegRuleReference,
    SegmentDto,
    SegmentFilter,
    SegmentListDto,
    SegmentReference,
    SegmentWarningDto,
    SegmentWarningsDto,
    SegmentationRuleDto,
    SegmentationRulesOwnersDto,
    SegmentsCountsDto,
    SegmentsCountsResponseDto,
    SegmentsCountsResponseListDto,
    ServiceProviderConfigDto,
    SetContextPTTransMemoriesV2Dto,
    SetContextTransMemoriesDtoV3Dto,
    SetFinancialSettingsDto,
    SetProjectStatusDto,
    SetProjectTemplateTermBaseDto,
    SetProjectTemplateTransMemoriesV2Dto,
    SetProjectTemplateTransMemoryV2Dto,
    SetProjectTransMemoriesV3Dto,
    SetProjectTransMemoryV3Dto,
    SetTermBaseDto,
    SettingsReference,
    SeverityDto,
    Sort,
    SourceTargetRegexpWarningDto,
    SpellCheckRequestDto,
    SpellCheckResponseDto,
    SpellCheckWarningDto,
    SplitJobActionDto,
    State,
    Status,
    Status12,
    Status2,
    Status24,
    Status28,
    Status3,
    Status4,
    Status6,
    Status7,
    Status8,
    StatusDto,
    StyleWeightsDto,
    SubDomainDto,
    SubDomainEditDto,
    SubDomainReference,
    SubDomainReference2,
    SubDomainReference3,
    SubstituteDto,
    SubstituteDtoV2,
    SuggestRequestDto,
    SuggestResponse,
    SuggestResponseDto,
    Suggestion,
    Suggestion2,
    Supported,
    TMMatchSettingsDto,
    TagMetadata,
    TagMetadataDto,
    TargetFileWarningsDto,
    TargetLanguageDto,
    TargetSourceIdenticalWarningDto,
    TaskMappingDto,
    TaskProcessingType,
    TaskType,
    Term,
    TermBaseDto,
    TermBaseEditDto,
    TermBaseReference,
    TermBaseSearchRequestDto,
    TermCreateByJobDto,
    TermCreateDto,
    TermDto,
    TermEditDto,
    TermPairDto,
    TermType,
    TermV2Dto,
    TerminologyWarningDto,
    TerminologyWeightsDto,
    ToggleableWeightDto,
    TrailingPunctuationWarningDto,
    TrailingSpaceWarningDto,
    TransMemoryCreateDto,
    TransMemoryDto,
    TransMemoryDtoV2,
    TransMemoryDtoV3,
    TransMemoryEditDto,
    TransMemoryReferenceDtoV2,
    TranslationDto,
    TranslationLengthWarningDto,
    TranslationMemorySettingsDto5,
    TranslationPriceDto,
    TranslationPriceListCreateDto,
    TranslationPriceListDto,
    TranslationPriceSetBulkDeleteDto,
    TranslationPriceSetBulkMinimumPricesDto,
    TranslationPriceSetBulkPricesDto,
    TranslationPriceSetCreateDto,
    TranslationPriceSetDto,
    TranslationPriceSetListDto,
    TranslationRequestDto,
    TranslationRequestExtendedDto,
    TranslationResourcesDto,
    TranslationSegmentsReferenceV2,
    TtxSettingsDto,
    TxtSettingsDto,
    TypesDto,
    USER,
    UidReference,
    Uniqueness,
    UnmodifiedFuzzyTranslationMTNTWarningDto,
    UnmodifiedFuzzyTranslationTMWarningDto,
    UnmodifiedFuzzyTranslationWarningDto,
    UnresolvedCommentWarningDto,
    UnresolvedConversationWarningDto,
    UpdateCustomFieldInstanceDto,
    UpdateCustomFieldInstanceWithUidDto,
    UpdateCustomFieldInstancesDto,
    UpdateCustomFileTypeDto,
    UpdateIgnoredChecksDto,
    UpdateIgnoredJobPartSegment,
    UpdateIgnoredSegment,
    UpdateIgnoredSegment2,
    UpdateIgnoredWarning,
    UpdateIgnoredWarning2,
    UpdateIgnoredWarningsDto,
    UpdateIgnoredWarningsDto_2,
    UpdateLqaProfileDto,
    UploadBilingualFileRequestDto,
    UploadResultDto,
    UploadedFileDto,
    User,
    UserDetailsDtoV3,
    UserDto,
    UserPasswordEditDto,
    UserReference,
    UserReference2,
    UserReference3,
    UserReferencesDto,
    UserStatisticsDto,
    UserStatisticsListDto,
    VENDOR,
    VOID,
    Vendor,
    VendorDto,
    VendorReference,
    VendorSecuritySettingsDto,
    VendorUserReference,
    VerityWeightsDto,
    WebEditorLinkDtoV2,
    WebHookDtoV2,
    WebhookCallDto,
    WebhookPreviewDto,
    WebhookPreviewsDto,
    WildCardSearchByJobRequestDtoV3,
    WildCardSearchRequestDto,
    WorkflowChangesDto,
    WorkflowStepConfiguration,
    WorkflowStepDto,
    WorkflowStepReference,
    WorkflowStepReference2,
    WorkflowStepReferenceV2,
    WorkflowStepReferenceV3,
    WorkflowStepSettingsDto,
    WorkflowStepSettingsEditDto,
    WorkflowStepSettingsEditV2Dto,
    Xlf2SettingsDto,
    XlfSettingsDto,
    XlsSettingsDto,
    XmlAssistantProfileListDto,
    XmlSettingsDto,
    YamlSettingsDto
    )
from .header_json_models import (
    CreateSegmentationRuleMeta,
    JobUpdateSourceMeta,
    JobUpdateTargetMeta,
    RateLimitsBaseModel,
    UploadFileV2Meta,
    UploadHandoverFileMeta
    )
from .added_models import (
    UpdateCustomFieldDto
    )



all = [
    ADMIN,
    ADMINEDIT,
    ADMINRESPONSE,
    AbsoluteTranslationLengthWarningDto,
    AbstractAnalyseSettingsDto,
    AbstractProjectDto,
    AbstractProjectDtoV2,
    AbstractUserCreateDto,
    AbstractUserEditDto,
    AccuracyWeightsDto,
    Action,
    Action1,
    AddCommentDto,
    AddLqaCommentResultDto,
    AddPlainCommentResultDto,
    AddTargetLangDto,
    AddWorkflowStepsDto,
    AdditionalWorkflowStepDto,
    AdditionalWorkflowStepRequestDto,
    AdditionalWorkflowStepV2Dto,
    AdminProjectManager,
    AdminProjectManagerV2,
    AllowedEntity,
    AnalyseJobDto,
    AnalyseJobReference,
    AnalyseLanguagePartDto,
    AnalyseLanguagePartReference,
    AnalyseLanguagePartV2Dto,
    AnalyseLanguagePartV3Dto,
    AnalyseRecalculateRequestDto,
    AnalyseRecalculateResponseDto,
    AnalyseReference,
    AnalyseSettingsDto,
    AnalyseV2Dto,
    AnalyseV3Dto,
    AnalysesV2Dto,
    AnalysisType_1,
    AnalysisType_2,
    AnalysisType_3,
    AndroidSettingsDto,
    AppleTokenResponseDto,
    AsciidocSettingsDto,
    AssessmentBasicDto,
    AssessmentDetailDto,
    AssessmentDetailsDto,
    AssessmentRequestDto,
    AssessmentResultDto,
    AssessmentResultsDto,
    AssignVendorDto,
    AssignableTemplatesDto,
    AssignedJobDto,
    AssignmentPerTargetLangDto,
    AsyncAnalyseListResponseDto,
    AsyncAnalyseListResponseV2Dto,
    AsyncAnalyseResponseDto,
    AsyncAnalyseResponseV2Dto,
    AsyncExportTMByQueryDto,
    AsyncExportTMByQueryResponseDto,
    AsyncExportTMDto,
    AsyncExportTMResponseDto,
    AsyncFileOpResponseDto,
    AsyncRequestDto,
    AsyncRequestReference,
    AsyncRequestReferenceDto,
    AsyncRequestStatusDto,
    AsyncRequestType,
    AsyncRequestV2Dto,
    AsyncRequestWrapperDto,
    AsyncRequestWrapperV2Dto,
    AsyncResponseDto,
    AsyncResponseV2Dto,
    Attribute,
    AttributeType,
    AuthSchema,
    AutomatedProjectSettingsDto,
    Availability,
    BackgroundTaskReference,
    BackgroundTasksTbDto,
    BackgroundTasksTmDto,
    BillingUnit,
    BillingUnit2,
    BrowseRequestDto,
    BrowseResponseListDto,
    BulkDeleteAnalyseDto,
    BulkDeleteTmDto,
    BulkEditAnalyseV2Dto,
    BusinessUnitDto,
    BusinessUnitEditDto,
    BusinessUnitReference,
    BusinessUnitReference2,
    BusinessUnitReference3,
    Buyer,
    BuyerDto,
    BuyerEditDto,
    BuyerReference,
    CellFlow,
    CheckResponse,
    CleanedTransMemoriesDto,
    CleanupTask,
    ClientDto,
    ClientEditDto,
    ClientReference,
    ClientReference2,
    ClientReference3,
    CloneProjectDto,
    CommentDto,
    CommonConversationDto,
    ComparedSegmentDto,
    ComparedSegmentsDto,
    ConceptDto,
    ConceptDtov2,
    ConceptEditDto,
    ConceptListReference,
    ConceptListResponseDto,
    ConceptWithMetadataDto,
    ConcurrentRequestsDto,
    ConnectorAsyncTaskStateDto,
    ConnectorAsyncTaskStatesDto,
    ConnectorDto,
    ConnectorErrorDetailDto,
    ConnectorErrorsDto,
    ConnectorListDto,
    ConnectorType,
    ContextKeySuffixType,
    ContextType,
    ContinuousJobInfoDto,
    ConversationListDto,
    CostCenterDto,
    CostCenterEditDto,
    CostCenterReference,
    CostCenterReference2,
    CountsDto,
    CountsDto2,
    CountsDto3,
    CreateAnalyseAsyncV2Dto,
    CreateAnalyseListAsyncDto,
    CreateCustomFieldDto,
    CreateCustomFieldInstanceDto,
    CreateCustomFieldInstancesDto,
    CreateCustomFileTypeDto,
    CreateLqaConversationDto,
    CreateLqaProfileDto,
    CreatePlainConversationDto,
    CreateProjectFromTemplateAsyncV2Dto,
    CreateProjectFromTemplateV2Dto,
    CreateProjectV3Dto,
    CreateReferenceFileNoteDto,
    CreateReferenceFilesRequest,
    CreateTermsDto,
    CreateVendorDto,
    CreateWebEditorLinkDtoV2,
    CreateWebHookDto,
    CreateWorkflowStepDto,
    CsvSettingsDto,
    CustomFieldDto,
    CustomFieldInstanceApiDto,
    CustomFieldInstanceApiV3Dto,
    CustomFieldInstanceDto,
    CustomFieldInstancesDto,
    CustomFieldOptionDto,
    CustomFieldOptionsTruncatedDto,
    CustomFileTypeDto,
    CustomFiletypeType,
    CustomQAWarningDto,
    CustomfieldType,
    DashboardSetting,
    DataDto,
    DataDto2,
    DataDtoV1,
    DeleteCustomFileTypeDto,
    DeleteVendorsDto,
    DelimiterType,
    DesignWeightsDto,
    DictionaryItemDto,
    Direction,
    DiscountSchemeCreateDto,
    DiscountSchemeReference,
    DiscountSchemeReference2,
    DiscountSettingsDto,
    DitaSettingsDto,
    DocBookSettingsDto,
    DocSettingsDto,
    DomainDto,
    DomainEditDto,
    DomainReference,
    DomainReference2,
    DomainReference3,
    DownloadTargetFileDto,
    EditAnalyseSettingsDto,
    EditAnalyseV2Dto,
    EditLqaConversationDto,
    EditPlainConversationDto,
    EditProjectMTSettPerLangDto,
    EditProjectMTSettPerLangListDto,
    EditProjectMTSettingsDto,
    EditProjectSecuritySettingsDtoV2,
    EditProjectV2Dto,
    EditProjectV3Dto,
    EditQASettingsDtoV2,
    EditSegmentationRuleDto,
    EditWorkflowStepDto,
    EditionDto,
    Email,
    EmailQuotesRequestDto,
    EmailQuotesResponseDto,
    EmailTemplateType,
    EmptyPairTagsWarningDto,
    EmptyTagContentWarningDto,
    EmptyTranslationWarningDto,
    EnabledCheck,
    EnabledCheckContextDtoV2,
    EnabledCheckContextDtoV4,
    EnabledCheckDtoV2,
    EnabledCheckDtoV4,
    EnabledQualityChecksDto,
    ErrorCategoriesDto,
    ErrorDetailDto,
    ErrorDetailDtoV2,
    ErrorDetailDtoV3,
    ErrorDto,
    ErrorsReference,
    Event,
    ExportByQueryDto,
    ExportTMDto,
    ExtraNumbersV3WarningDto,
    ExtraNumbersWarningDto,
    FeaturesDto,
    FileDto,
    FileFormat,
    FileHandoverDto,
    FileImportSettingsCreateDto,
    FileImportSettingsDto,
    FileListDto,
    FileNamingSettingsDto,
    Filter,
    FinancialSettingsDto,
    FindConversationsDto,
    FindConversationsForProjectDto,
    FinishAssessmentDto,
    FinishAssessmentItemDto,
    FinishAssessmentsDto,
    Flavor,
    FluencyWeightsDto,
    ForbiddenStringWarningDto,
    ForbiddenTermWarningDto,
    FormattingWarningDto,
    FuzzyInconsistencyWarningDto,
    GUEST,
    GUESTEDIT,
    GUESTRESPONSE,
    Gender,
    GetBilingualFileDto,
    GetFileRequestParamsDto,
    GlossaryActivationDto,
    GlossaryDto,
    GlossaryEditDto,
    GlossarySimpleDto,
    HtmlSettingsDto,
    HumanTranslateJobsDto,
    IdReference,
    IdmUserReference,
    IdmlSettingsDto,
    ImportSetSegmentConfirmedWhen,
    ImportSettingsCreateDto,
    ImportSettingsDto,
    ImportSettingsEditDto,
    ImportSettingsReference,
    ImportStatusDto,
    ImportStatusDtoV2,
    ImportTermBaseResponseDto,
    InconsistentTagContentWarningDto,
    InconsistentTranslationWarningDto,
    InputStream,
    InputStreamLength,
    IssueCountsDto,
    JobCreateRemoteFileDto,
    JobCreateRequestDto,
    JobExportActionDto,
    JobExportResponseDto,
    JobListDto,
    JobMachineTranslationSettingsV3Dto,
    JobNonTranslatableSettingsV3Dto,
    JobPartDeleteReferences,
    JobPartExtendedDto,
    JobPartPatchBatchDto,
    JobPartPatchResultDto,
    JobPartPatchSingleDto,
    JobPartReadyDeleteTranslationDto,
    JobPartReadyDeleteTranslationFilterDto,
    JobPartReadyReferences,
    JobPartReadyReferences2,
    JobPartReference,
    JobPartReferenceV2,
    JobPartReferences,
    JobPartSegmentsDtoV3,
    JobPartStatusChangeDto,
    JobPartStatusChangesDto,
    JobPartUpdateBatchDto,
    JobPartUpdateSingleDto,
    JobPartUpdateSourceDto,
    JobPartsDto,
    JobReference,
    JobRemoteFileReference,
    JobRoleDto,
    JobSegmentDto,
    JobStatusChangeActionDto,
    JobTranslationMemorySettingsV3Dto,
    JobUpdateSourceResponseDto,
    JobWidgetReference,
    JobroleType,
    JoinTagsWarningDto,
    JsonSettingsDto,
    LINGUIST,
    LINGUISTEDIT,
    LINGUISTRESPONSE,
    LQA,
    LQAConversationDto,
    LQAConversationsListDto,
    LQAReference,
    LQAReferences,
    LanguageDto2,
    LanguageListDto,
    LanguageMetadata,
    LanguageMetadata1,
    LastLoginDto,
    LeadingAndTrailingSpacesWarningDto,
    Level,
    Linguist,
    LinguistV2,
    LocaleConventionWeightsDto,
    LocaleFormat,
    LoginDto,
    LoginOtherDto,
    LoginOtherV3Dto,
    LoginResponseDto,
    LoginResponseV3Dto,
    LoginToSessionDto,
    LoginToSessionResponseDto,
    LoginToSessionResponseV3Dto,
    LoginToSessionV3Dto,
    LoginUserDto,
    LoginV3Dto,
    LoginWithAppleDto,
    LoginWithGoogleDto,
    LqaErrorCategoryDto,
    LqaProfileAssessmentDto,
    LqaProfileDetailDto,
    LqaProfileReferenceDto,
    LqaProfilesForWsV2Dto,
    LqaProfilesForWsV3Dto,
    LqaRecipientType,
    LqaReportEmailRequestDto,
    LqaReportLinkDto,
    LqaReportRecipientDto,
    LqaSettingsDto,
    LqaSeverityDto,
    MORAVIA,
    MTSettingsPerLanguageDto,
    MTSettingsPerLanguageListDto,
    MTSettingsPerLanguageReference,
    MacSettingsDto,
    MachineTranslateResponse,
    MachineTranslateSettingsDto,
    MachineTranslateSettingsLangsDto,
    MachineTranslateSettingsPbmDto,
    MachineTranslateSettingsReference,
    MachineTranslateSettingsSimpleDto,
    MachineTranslateStatusDto,
    MachineTranslationBehavior,
    MachineTranslationSettingsDto5,
    MalformedWarningDto,
    Match,
    MatchCounts101Dto,
    MatchCounts101Dto2,
    MatchCounts101Dto3,
    MatchCountsDto,
    MatchCountsDto2,
    MatchCountsDto3,
    MatchCountsNTDto,
    MatchCountsNTDto2,
    MatchCountsNTDtoV1,
    MdSettingsDto,
    MemTransMachineTranslateSettingsDto,
    MemsourceTranslateProfileDto,
    MemsourceTranslateProfileSimpleDto,
    MentionDto,
    MentionGroupType,
    MentionType,
    MentionableGroupDto,
    MentionableUserDto,
    MetadataField,
    MetadataOptionReference,
    MetadataPrioritySettingsDto,
    MetadataReference,
    MetadataResponse,
    MetadataResponse_2,
    MetadataTbDto,
    MetadataType,
    MifSettingsDto,
    MissingNonTranslatableAnnotationWarningDto,
    MissingNumbersV3WarningDto,
    MissingNumbersWarningDto,
    MisspelledWord,
    MisspelledWordDto,
    Mode,
    MoraviaWarningDto,
    MultilingualCsvSettingsDto,
    MultilingualXlsSettingsDto,
    MultilingualXmlSettingsDto,
    MultipartFile,
    MultipleSpacesV3WarningDto,
    MultipleSpacesWarningDto,
    Mutability,
    NUMBER,
    Name,
    NameDto,
    NestedTagsWarningDto,
    NetRateScheme,
    NetRateSchemeEdit,
    NetRateSchemeReference,
    NetRateSchemeWorkflowStep,
    NetRateSchemeWorkflowStepCreate,
    NetRateSchemeWorkflowStepEdit,
    NetRateSchemeWorkflowStepReference,
    NewerAtLowerLevelWarningDto,
    NonConformingTermWarningDto,
    NonEmptySegmentAction,
    NonTranslatableSettingsDto5,
    NotConfirmedWarningDto,
    NotificationDto,
    NotifyJobPartsRequestDto,
    NotifyProviderDto,
    Number,
    Number1,
    ObjectReference,
    Order,
    OrganizationEmailTemplateDto,
    OrganizationReference,
    OrganizationReference2,
    OrganizationType,
    Origin,
    Origin1,
    OtherWeightsDto,
    OutputFormat,
    PORTALMEMBER,
    PORTALMEMBEREDIT,
    PORTALMEMBERRESPONSE,
    PROJECTMANAGER,
    PROJECTMANAGEREDIT,
    PROJECTMANAGERRESPONSE,
    PageDtoAbstractProjectDto,
    PageDtoAdditionalWorkflowStepDto,
    PageDtoAnalyseJobDto,
    PageDtoAnalyseReference,
    PageDtoAssignedJobDto,
    PageDtoAsyncRequestDto,
    PageDtoBusinessUnitDto,
    PageDtoBuyerDto,
    PageDtoClientDto,
    PageDtoCommonConversationDto,
    PageDtoCostCenterDto,
    PageDtoCustomFieldDto,
    PageDtoCustomFieldInstanceDto,
    PageDtoCustomFieldOptionDto,
    PageDtoCustomFileTypeDto,
    PageDtoDomainDto,
    PageDtoGlossaryDto,
    PageDtoImportSettingsReference,
    PageDtoJobPartReferenceV2,
    PageDtoLastLoginDto,
    PageDtoLqaProfileReferenceDto,
    PageDtoLqaReportRecipientDto,
    PageDtoMachineTranslateSettingsPbmDto,
    PageDtoMemsourceTranslateProfileDto,
    PageDtoNetRateSchemeReference,
    PageDtoNetRateSchemeWorkflowStepReference,
    PageDtoOrganizationEmailTemplateDto,
    PageDtoProjectReference,
    PageDtoProjectTemplateReference,
    PageDtoProviderReference,
    PageDtoQuoteDto,
    PageDtoSegmentationRuleDto,
    PageDtoString,
    PageDtoSubDomainDto,
    PageDtoTermBaseDto,
    PageDtoTransMemoryDto,
    PageDtoTranslationPriceListDto,
    PageDtoTranslationPriceSetDto,
    PageDtoUploadedFileDto,
    PageDtoUserDto,
    PageDtoUserReference,
    PageDtoVendorDto,
    PageDtoWebHookDtoV2,
    PageDtoWebhookCallDto,
    PageDtoWorkflowStepDto,
    PageDtoWorkflowStepReference,
    PageDtoXmlAssistantProfileListDto,
    PageRequest,
    PageWithResponseTsDtoNotificationDto,
    PartOfSpeech,
    PassFailThresholdDto,
    PatchProjectDto,
    PdfSettingsDto,
    PenaltyPointsDto,
    PhpSettingsDto,
    PlainConversationDto,
    PlainConversationsListDto,
    PlainReferences,
    PoSettingsDto,
    Position,
    PostAnalyse,
    PptSettingsDto,
    PreAnalyse,
    PreAnalyseTargetCompare,
    PreTranslateJobSettingsV3Dto,
    PreTranslateJobsV3Dto,
    PreTranslateSettingsV4Dto,
    PreviewUrlDto,
    PreviewUrlType,
    PreviewUrlsDto,
    PreviousWorkflowDto,
    PriceListReference,
    ProgressDto,
    ProgressDtoV2,
    ProgressReference,
    ProjectJobPartsDto,
    ProjectMTSettingsPerLangDto,
    ProjectReference,
    ProjectReference2,
    ProjectReferenceFilesRequestDto,
    ProjectSecuritySettingsDtoV2,
    ProjectTemplate,
    ProjectTemplateCreateActionDto,
    ProjectTemplateDto,
    ProjectTemplateEditDto,
    ProjectTemplateEditV2Dto,
    ProjectTemplateNotifyProviderDto,
    ProjectTemplateReference,
    ProjectTemplateTermBaseDto,
    ProjectTemplateTermBaseListDto,
    ProjectTemplateTransMemoryDtoV3,
    ProjectTemplateTransMemoryListDtoV3,
    ProjectTemplateTransMemoryListV2Dto,
    ProjectTemplateTransMemoryV2Dto,
    ProjectTemplateWorkflowSettingsAssignedToDto,
    ProjectTemplateWorkflowSettingsDto,
    ProjectTermBaseDto,
    ProjectTermBaseListDto,
    ProjectTermBaseReference,
    ProjectTransMemoryDtoV3,
    ProjectTransMemoryListDtoV3,
    ProjectTranslationMemoryReference,
    ProjectWorkflowSettingsDto,
    ProjectWorkflowSettingsReference,
    ProjectWorkflowSettingsV2Dto,
    ProjectWorkflowStepDto,
    ProjectWorkflowStepDtoV2,
    ProjectWorkflowStepListDtoV2,
    ProjectWorkflowStepReference,
    PropertiesSettingsDto,
    ProviderListDtoV2,
    ProviderReference,
    ProviderReference2,
    Providers2,
    ProvidersPerLanguage,
    PsdSettingsDto,
    PseudoTranslateActionDto,
    PseudoTranslateActionDtoV2,
    PseudoTranslateWrapperDto,
    QACheckDtoV2,
    QASettingsDtoV2,
    QaCheckName,
    QaCheckType,
    QualityAssuranceBatchRunDtoV3,
    QualityAssuranceChecksDtoV2,
    QualityAssuranceChecksDtoV4,
    QualityAssuranceDto,
    QualityAssuranceResponseDto,
    QualityAssuranceRunDtoV3,
    QualityAssuranceSegmentsRunDtoV3,
    QuarkTagSettingsDto,
    Query,
    QuoteCreateV2Dto,
    QuoteDto,
    QuoteType,
    QuoteUnitsDto,
    QuoteV2Dto,
    QuoteWorkflowSettingDto,
    REGEX,
    ReferenceCorrelation,
    ReferenceFileAccessDto,
    ReferenceFilePageDto,
    ReferenceFileReference,
    ReferenceFilesDto,
    RegexpCheckRuleDtoV2,
    RegexpCheckRuleDtoV4,
    RelativeTranslationLengthWarningDto,
    RemoteUploadedFileDto,
    Repeated,
    RepeatedWordWarningDto,
    RepeatedWordsWarningDto,
    RepetitionsSettingsDto4,
    ReplayRequestDto,
    ResxSettingsDto,
    Returned,
    ReviewProviderDto,
    Role,
    Role4,
    Role5,
    RulesFormat,
    RunAutoLqaDto,
    SEGMENTTARGET,
    STRING,
    SUBMITTER,
    SUBMITTEREDIT,
    SUBMITTERRESPONSE,
    SchemaExtension,
    ScimMeta,
    ScimResourceSchema,
    ScimResourceTypeSchema,
    ScimUserCoreDto,
    ScoringResultDto,
    ScoringResultIssueCountsDto,
    SdlXlfSettingsDto,
    SearchInTextResponse2Dto,
    SearchInTextResponseList2Dto,
    SearchJobsDto,
    SearchJobsRequestDto,
    SearchRequestDto,
    SearchResponseListTbDto,
    SearchResponseListTmDto,
    SearchResponseListTmDtoV3,
    SearchResponseTbDto,
    SearchTMByJobRequestDto,
    SearchTMByJobRequestDtoV3,
    SearchTMClientDto,
    SearchTMClientDtoV3,
    SearchTMDomainDto,
    SearchTMDomainDtoV3,
    SearchTMProjectDto,
    SearchTMProjectDtoV3,
    SearchTMRequestDto,
    SearchTMResponseDto,
    SearchTMResponseDtoV3,
    SearchTMSegmentDto,
    SearchTMSegmentDtoV3,
    SearchTMSubDomainDto,
    SearchTMSubDomainDtoV3,
    SearchTMTransMemoryDto,
    SearchTMTransMemoryDtoV3,
    SearchTbByJobRequestDto,
    SearchTbInTextByJobRequestDto,
    SearchTbResponseDto,
    SearchTbResponseListDto,
    SecuritySettingsReference,
    SegRuleReference,
    SegmentDto,
    SegmentFilter,
    SegmentListDto,
    SegmentReference,
    SegmentWarningDto,
    SegmentWarningsDto,
    SegmentationRuleDto,
    SegmentationRulesOwnersDto,
    SegmentsCountsDto,
    SegmentsCountsResponseDto,
    SegmentsCountsResponseListDto,
    ServiceProviderConfigDto,
    SetContextPTTransMemoriesV2Dto,
    SetContextTransMemoriesDtoV3Dto,
    SetFinancialSettingsDto,
    SetProjectStatusDto,
    SetProjectTemplateTermBaseDto,
    SetProjectTemplateTransMemoriesV2Dto,
    SetProjectTemplateTransMemoryV2Dto,
    SetProjectTransMemoriesV3Dto,
    SetProjectTransMemoryV3Dto,
    SetTermBaseDto,
    SettingsReference,
    SeverityDto,
    Sort,
    SourceTargetRegexpWarningDto,
    SpellCheckRequestDto,
    SpellCheckResponseDto,
    SpellCheckWarningDto,
    SplitJobActionDto,
    State,
    Status,
    Status12,
    Status2,
    Status24,
    Status28,
    Status3,
    Status4,
    Status6,
    Status7,
    Status8,
    StatusDto,
    StyleWeightsDto,
    SubDomainDto,
    SubDomainEditDto,
    SubDomainReference,
    SubDomainReference2,
    SubDomainReference3,
    SubstituteDto,
    SubstituteDtoV2,
    SuggestRequestDto,
    SuggestResponse,
    SuggestResponseDto,
    Suggestion,
    Suggestion2,
    Supported,
    TMMatchSettingsDto,
    TagMetadata,
    TagMetadataDto,
    TargetFileWarningsDto,
    TargetLanguageDto,
    TargetSourceIdenticalWarningDto,
    TaskMappingDto,
    TaskProcessingType,
    TaskType,
    Term,
    TermBaseDto,
    TermBaseEditDto,
    TermBaseReference,
    TermBaseSearchRequestDto,
    TermCreateByJobDto,
    TermCreateDto,
    TermDto,
    TermEditDto,
    TermPairDto,
    TermType,
    TermV2Dto,
    TerminologyWarningDto,
    TerminologyWeightsDto,
    ToggleableWeightDto,
    TrailingPunctuationWarningDto,
    TrailingSpaceWarningDto,
    TransMemoryCreateDto,
    TransMemoryDto,
    TransMemoryDtoV2,
    TransMemoryDtoV3,
    TransMemoryEditDto,
    TransMemoryReferenceDtoV2,
    TranslationDto,
    TranslationLengthWarningDto,
    TranslationMemorySettingsDto5,
    TranslationPriceDto,
    TranslationPriceListCreateDto,
    TranslationPriceListDto,
    TranslationPriceSetBulkDeleteDto,
    TranslationPriceSetBulkMinimumPricesDto,
    TranslationPriceSetBulkPricesDto,
    TranslationPriceSetCreateDto,
    TranslationPriceSetDto,
    TranslationPriceSetListDto,
    TranslationRequestDto,
    TranslationRequestExtendedDto,
    TranslationResourcesDto,
    TranslationSegmentsReferenceV2,
    TtxSettingsDto,
    TxtSettingsDto,
    TypesDto,
    USER,
    UidReference,
    Uniqueness,
    UnmodifiedFuzzyTranslationMTNTWarningDto,
    UnmodifiedFuzzyTranslationTMWarningDto,
    UnmodifiedFuzzyTranslationWarningDto,
    UnresolvedCommentWarningDto,
    UnresolvedConversationWarningDto,
    UpdateCustomFieldInstanceDto,
    UpdateCustomFieldInstanceWithUidDto,
    UpdateCustomFieldInstancesDto,
    UpdateCustomFileTypeDto,
    UpdateIgnoredChecksDto,
    UpdateIgnoredJobPartSegment,
    UpdateIgnoredSegment,
    UpdateIgnoredSegment2,
    UpdateIgnoredWarning,
    UpdateIgnoredWarning2,
    UpdateIgnoredWarningsDto,
    UpdateIgnoredWarningsDto_2,
    UpdateLqaProfileDto,
    UploadBilingualFileRequestDto,
    UploadResultDto,
    UploadedFileDto,
    User,
    UserDetailsDtoV3,
    UserDto,
    UserPasswordEditDto,
    UserReference,
    UserReference2,
    UserReference3,
    UserReferencesDto,
    UserStatisticsDto,
    UserStatisticsListDto,
    VENDOR,
    VOID,
    Vendor,
    VendorDto,
    VendorReference,
    VendorSecuritySettingsDto,
    VendorUserReference,
    VerityWeightsDto,
    WebEditorLinkDtoV2,
    WebHookDtoV2,
    WebhookCallDto,
    WebhookPreviewDto,
    WebhookPreviewsDto,
    WildCardSearchByJobRequestDtoV3,
    WildCardSearchRequestDto,
    WorkflowChangesDto,
    WorkflowStepConfiguration,
    WorkflowStepDto,
    WorkflowStepReference,
    WorkflowStepReference2,
    WorkflowStepReferenceV2,
    WorkflowStepReferenceV3,
    WorkflowStepSettingsDto,
    WorkflowStepSettingsEditDto,
    WorkflowStepSettingsEditV2Dto,
    Xlf2SettingsDto,
    XlfSettingsDto,
    XlsSettingsDto,
    XmlAssistantProfileListDto,
    XmlSettingsDto,
    YamlSettingsDto,
    CreateSegmentationRuleMeta,
    JobUpdateSourceMeta,
    JobUpdateTargetMeta,
    RateLimitsBaseModel,
    UploadFileV2Meta,
    UploadHandoverFileMeta,
    UpdateCustomFieldDto,
    
]