from .additional_workflow_step import AdditionalWorkflowStepOperations
from .analysis import AnalysisOperations
from .async_request import AsyncRequestOperations
from .authentication import AuthenticationOperations
from .bilingual_file import BilingualFileOperations
from .business_unit import BusinessUnitOperations
from .buyer import BuyerOperations
from .client import ClientOperations
from .connector import ConnectorOperations
from .cost_center import CostCenterOperations
from .custom_fields import CustomFieldsOperations
from .custom_file_type import CustomFileTypeOperations
from .domain import DomainOperations
from .email_template import EmailTemplateOperations
from .file import FileOperations
from .glossary import GlossaryOperations
from .importsettings import ImportsettingsOperations
from .conversations import ConversationsOperations
from .supported_languages import SupportedLanguagesOperations
from .language_quality_assessment import LanguageQualityAssessmentOperations
from .quality_assurance import QualityAssuranceOperations
from .machine_translation_settings import MachineTranslationSettingsOperations
from .machine_translation import MachineTranslationOperations
from .mapping import MappingOperations
from .language_ai import LanguageAIOperations
from .net_rate_scheme import NetRateSchemeOperations
from .notifications import NotificationsOperations
from .price_list import PriceListOperations
from .project_template import ProjectTemplateOperations
from .term_base import TermBaseOperations
from .translation_memory import TranslationMemoryOperations
from .project import ProjectOperations
from .job import JobOperations
from .translation import TranslationOperations
from .segment import SegmentOperations
from .provider import ProviderOperations
from .project_reference_file import ProjectReferenceFileOperations
from .quote import QuoteOperations
from .scim import SCIMOperations
from .segmentation_rules import SegmentationRulesOperations
from .spell_check import SpellCheckOperations
from .sub_domain import SubDomainOperations
from .user import UserOperations
from .workflow_step import WorkflowStepOperations
from .vendor import VendorOperations
from .webhook import WebhookOperations
from .xml_assistant import XMLAssistantOperations
from .workflowchanges import WorkflowchangesOperations



all = [
    AdditionalWorkflowStepOperations,
    AnalysisOperations,
    AsyncRequestOperations,
    AuthenticationOperations,
    BilingualFileOperations,
    BusinessUnitOperations,
    BuyerOperations,
    ClientOperations,
    ConnectorOperations,
    CostCenterOperations,
    CustomFieldsOperations,
    CustomFileTypeOperations,
    DomainOperations,
    EmailTemplateOperations,
    FileOperations,
    GlossaryOperations,
    ImportsettingsOperations,
    ConversationsOperations,
    SupportedLanguagesOperations,
    LanguageQualityAssessmentOperations,
    QualityAssuranceOperations,
    MachineTranslationSettingsOperations,
    MachineTranslationOperations,
    MappingOperations,
    LanguageAIOperations,
    NetRateSchemeOperations,
    NotificationsOperations,
    PriceListOperations,
    ProjectTemplateOperations,
    TermBaseOperations,
    TranslationMemoryOperations,
    ProjectOperations,
    JobOperations,
    TranslationOperations,
    SegmentOperations,
    ProviderOperations,
    ProjectReferenceFileOperations,
    QuoteOperations,
    SCIMOperations,
    SegmentationRulesOperations,
    SpellCheckOperations,
    SubDomainOperations,
    UserOperations,
    WorkflowStepOperations,
    VendorOperations,
    WebhookOperations,
    XMLAssistantOperations,
    WorkflowchangesOperations
    
]